:mod:`cv.models`
----------------

Reference for :mod:`cv.models` generated from docstrings.

Publications
============
.. automodule:: cv.models.publications
   :members:

Works
=====
.. automodule:: cv.models.works
   :members:

Base Models
===========
.. automodule:: cv.models.base
   :members:

